Learn R Programming

colt (version 0.1.1)

colt-package: Colt - CLI color themes for R

Description

Colt is aimed at package developers that want to create themeable command line output. It is a simple wrapper around the crayon package.

Arguments

See Also

Useful links: