powered by
Colt is aimed at package developers that want to create themeable command line output. It is a simple wrapper around the crayon package.
Useful links:
https://github.com/s-fleck/colt
Report bugs at https://github.com/s-fleck/colt/issues